Module validators

Module validators 

The functions executing the validation logic. These are called by the validators added by protocheck-proc-macro to the target structs.

Modules

bytesbytes
Validators for bytes fields.
celcel
Cel validation for messages or message fields.
comparables
Validators for types that are comparable (PartialOrd, PartialEq)
constants
Validators for constant fields.
containing
Validators for lists of allowed (or forbidden) values.
enums
Validators for enum fields.
floats
Validators for floating point numbers (f32 and f64).
maps
Validators for protobuf maps.
oneofs
Validators for protobuf oneofs.
repeated
Validators for repeated fields.
required
Validators for fields that are marked as “required” in the protovalidate annotations.
static_data
All the static data being used by validators, such as definitions for protovalidate violations.
string
Validators for strings.
timestamps
Validators for timestamp fields.